__all__ = [
    "__title__",
    "__summary__",
    "__uri__",
    "__version__",
    "__author__",
    "__email__",
    "__license__",
    "__copyright__",
]

__title__ = "flasket"
__summary__ = "A small flask - A flask+connexion ensemble to quickly deploy an app."
__uri__ = "https://gitlab.com/jlecomte/projects/flasket"

__version__ = "0.1.8"

__author__ = "Julien Lecomte"
__email__ = "julien@lecomte.at"

__license__ = "MIT"
__copyright__ = "2022-2022 %s" % __author__
